@@ -73,14 +73,14 @@ class ProxyGetter(metaclass=ProxyMeta):
         :return:
         """
         proxies = []
+        res = eval(f'self.{self.name}()')
         try:
-            res = eval(f'self.{self.name}()')
             if isinstance(res, dict):
                 return res
             for proxy in res:
                 proxies.append(proxy)
         except Exception as e:
-            print(f"{self.name}:{e}")
+            print(f"{self.name}:{e}{res}")
         if proxies:
             return proxies
 
