@@ -109,8 +109,8 @@ class Cookies:
     def input_time_random(self):
         return random.randint(100, 151)
 
-    def taobao_cookies(self, us):
-        url = 'https://login.taobao.com/member/login.jhtml?'
+    def taobao_cookies(self, us, url):
+        # url = 'https://login.taobao.com/member/login.jhtml?'
         loop1 = asyncio.new_event_loop()
         asyncio.set_event_loop(loop1)
         loop = asyncio.get_event_loop()
